@@ -2,14 +2,13 @@ from __future__ import print_function
 
 from decimal import Decimal
 from traceback import format_exc
-from inspect import isfunction, ismethod
 
 
 from .errors import Error
 from .parser import parse
 from .lexer import tokenize
 from .version import version
-from .utils import format_function, format_method, tryimport
+from .utils import format_result, tryimport
 
 from .core import Core
 from .types import Types
@@ -68,6 +67,7 @@ class State(object):
         self._value = value
 
     def bootstrap(self):
+        # Fake Object to solve chicken/egg problem.
         self.root = {"Object": None}
 
         object = Object()
@@ -82,6 +82,7 @@ class State(object):
 
     def initialize(self):
         root = self.root
+
         root["Types"] = Types()
         root["Core"] = Core()
 
@@ -151,17 +152,7 @@ class State(object):
                 if code:
                     result = self.eval(code)
                     if result is not None:  # pragma: no cover
-                        if isinstance(result, Object):
-                            if result.value is not None:
-                                output = self.eval("__repr__()", receiver=result)
-                            else:
-                                output = None
-                        elif ismethod(result):
-                            output = format_method(result)
-                        elif isfunction(result):
-                            output = format_function(result)
-                        else:
-                            output = repr(result)
+                        output = format_result(result)
                         if output is not None:
                             print("===> {0:s}".format(output))
             except EOFError:  # pragma: no cover
